@@ -12,8 +12,7 @@ class Normalize(nn.Module):
     def forward(self, input: Tensor) -> Tensor:
         # input: (N, style_dim)
         # Normalize z in each sample to N(0,1)
-        return input * torch.rsqrt(
-            torch.mean(input**2, dim=1, keepdim=True) + 1e-8)
+        return input * torch.rsqrt(torch.mean(input ** 2, dim=1, keepdim=True) + 1e-8)
 
 
 class MappingNetwork(nn.Sequential):
@@ -23,10 +22,13 @@ class MappingNetwork(nn.Sequential):
 
     def __init__(self, latent_dim: int, n_mlp: int, lr_mlp_mult: float):
         super().__init__(
-            Normalize(), *[
+            Normalize(),
+            *[
                 EqualLeakyReLU(
                     latent_dim,
                     latent_dim,
                     lr_mult=lr_mlp_mult,
-                ) for _ in range(n_mlp)
-            ])
+                )
+                for _ in range(n_mlp)
+            ]
+        )
